@@ -7,7 +7,7 @@ from django.utils import simplejson
 
 from django.utils.translation import ugettext
 
-from inplaceeditform.commons import apply_filters, import_module, has_transmeta, get_static_url
+from inplaceeditform.commons import apply_filters, import_module, has_transmeta, get_static_url, get_admin_static_url
 from inplaceeditform.perms import SuperUserPermEditInline
 
 
@@ -58,7 +58,26 @@ class BaseAdaptorField(object):
 
     @classmethod
     def get_config(self, **kwargs):
-        return kwargs
+        """
+        Get the arguments given to the template tag element and complete these
+        with the ones from the settings.py if necessary.
+        """
+        config = kwargs
+
+        config_from_settings = getattr(
+            settings, "DEFAULT_INPLACE_EDIT_OPTIONS", {})
+        config_one_by_one = getattr(
+            settings, "DEFAULT_INPLACE_EDIT_OPTIONS_ONE_BY_ONE", False)
+
+        if not config_one_by_one:
+            # Solution 1: Using default config only if none specified.
+            if not config and config_from_settings:
+                config = config_from_settings
+        else:
+            # Solution 2: Updating the configured config with the default one.
+            config = dict(config_from_settings, **config)
+
+        return config
 
     def get_form_class(self):
         return modelform_factory(self.model)
@@ -107,7 +126,7 @@ class BaseAdaptorField(object):
         extra_context = extra_context or {}
         context = {'field': self.get_field(),
                    'STATIC_URL': get_static_url(),
-                   'ADMIN_MEDIA_PREFIX': settings.ADMIN_MEDIA_PREFIX}
+                   'ADMIN_MEDIA_PREFIX': get_admin_static_url()}
         context.update(extra_context)
 
         return render_to_string(template_name, context)
@@ -413,7 +432,11 @@ class AdaptorFileField(BaseAdaptorField):
         return render_to_string(template_name, config)
 
     def save(self, value):
-        getattr(self.obj, self.field_name).save(value.name, value)
+        file_name = value and value.name
+        if not file_name:
+            super(AdaptorFileField, self).save(value)
+        else:
+            getattr(self.obj, self.field_name).save(file_name, value)
 
 
 class AdaptorImageField(AdaptorFileField):
